import argparse
from .collection import DottedDict


def edit_json(key, value, file):
    import json
    try:
        with open(file) as json_file:
            data = json.load(json_file)
    except IOError:
        data = {}
    data = DottedDict(data)
    data[key] = value
    with open(file, 'w') as json_file:
        json_file.write(data.to_json())


def main():
    """The entrypoint to CLI app."""
    epilog = None
    parser = argparse.ArgumentParser(description='Simple data editor.',
                                     epilog=epilog,
                                     prog='sde')
    parser.add_argument('key', metavar='<key>', help='Key to edit')
    parser.add_argument('val', metavar='<val>', help='New value')
    parser.add_argument('file', metavar='<filename>', help='Filename to edit')
    args = parser.parse_args()
    
    if args.file.endswith('.json'):
        edit_json(args.key, args.val, args.file)


"""
sde
==========
License: BSD, see LICENSE for more details.
"""

__author__ = "Danila Vershinin"

import logging

from .__about__ import (
    __version__,
)

from .sde import main
from .sde import edit_json

# https://realpython.com/python-logging-source-code/#library-vs-application-logging-what-is-nullhandler
# when used as library, we default to opt-in approach, whereas library user have to enable logging
# from lastversion
logging.getLogger(__name__).addHandler(logging.NullHandler())

